import { useGraphQueryResult, useSchemaGraph } from '../../data-access/store';
import React, { useMemo, useRef } from 'react';
import { Table, AugmentedNodeAttributes } from './components/Table';
import { SchemaAttribute } from '../../schema';

export const TableVis = React.memo(({ showBarplot }: { showBarplot: boolean }) => {
  const ref = useRef<HTMLDivElement>(null);
  const graphQueryResult = useGraphQueryResult();
  const schema = useSchemaGraph();

  const attributesArray = useMemo<AugmentedNodeAttributes[]>(
    () =>
      graphQueryResult.nodes.map((node) => {
        const types: SchemaAttribute[] =
          schema.nodes.find((n) => n.key === node.label)?.attributes?.attributes ??
          schema.edges.find((r) => r.key === node.label)?.attributes?.attributes ??
          [];

        return {
          attribute: node.attributes,
          type: Object.fromEntries(types.map((t) => [t.name, t.type])),
        };
      }),
    [graphQueryResult.nodes],
  );

  return (
    <>
      <div className="h-full w-full" ref={ref}>
        {attributesArray.length > 0 && <Table data={attributesArray} itemsPerPage={10} showBarPlot={showBarplot} />}
      </div>
    </>
  );
});

TableVis.displayName = 'TableVis';

export default TableVis;
