import React from 'react';
import { Meta } from '@storybook/react';
import { TableVis } from './tableVis';

import {
  assignNewGraphQueryResult,
  graphQueryResultSlice,
  schemaSlice,
  setSchema,
} from '../../data-access/store';
import { configureStore } from '@reduxjs/toolkit';
import { Provider } from 'react-redux';
import { smallFlightsQueryResults, simpleSchemaRaw, bigMockQueryResults } from '../../mock-data';

import { SchemaUtils } from '../../schema/schema-utils';
import { simpleSchemaAirportRaw } from '../../mock-data/schema/simpleAirportRaw';

const Component: Meta<typeof TableVis> = {
  /* 👇 The title prop is optional.
   * See https://storybook.js.org/docs/react/configure/overview#configure-story-loading
   * to learn how to generate automatic titles
   */
  title: 'Visualizations/SimpleTableVis',
  component: TableVis,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <div
          style={{
            width: '100%',
            height: '100vh',
          }}
        >
          {story()}
        </div>
      </Provider>
    ),
  ],
};

const Mockstore = configureStore({
  reducer: {
    schema: schemaSlice.reducer,
    graphQueryResult: graphQueryResultSlice.reducer,
  },
});

/*
export const TestWithBig2ndChamber = {
  args: { loading: false },
  play: async () => {
    const dispatch = Mockstore.dispatch;

    dispatch(assignNewGraphQueryResult({ queryID: '1', result: { type: 'nodelink', payload: big2ndChamberQueryResult } }));
  },
};
*/

export const TestWithAirport = {
  args: {
    loading: false,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    const schema = SchemaUtils.schemaBackend2Graphology(simpleSchemaAirportRaw);

    dispatch(setSchema(schema.export()));
    dispatch(assignNewGraphQueryResult({ queryID: '1', result: { type: 'nodelink', payload: bigMockQueryResults } }));
  },
};

export default Component;

export const TestWithAirportSimple = {
  args: {
    loading: false,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    const schema = SchemaUtils.schemaBackend2Graphology(simpleSchemaRaw);

    dispatch(setSchema(schema.export()));
    dispatch(assignNewGraphQueryResult({ queryID: '1', result: { type: 'nodelink', payload: smallFlightsQueryResults } }));
  },
};
